@@ -1,3 +1,8 @@
+/*!
+Atomic-Server is mostly desgigned to run as a binary, but it can be embedded in other projects, too.
+It is currently used as an embedded server in the Tauri distribution of Atomic Server.
+See https://github.com/joepio/atomic-data-rust/tree/master/src-tauri
+*/
 mod actor_messages;
 mod appstate;
 mod commit_monitor;
@@ -18,5 +23,3 @@ mod search;
 mod tests;
 mod timer;
 mod trace;
-#[cfg(feature = "desktop")]
-mod tray_icon;
