@@ -1,7 +1,6 @@
 use actix_cors::Cors;
 use actix_web::{middleware, web, HttpServer};
 use atomic_lib::Storelike;
-use std::sync::Mutex;
 
 use crate::errors::AtomicServerResult;
 
@@ -42,24 +41,15 @@ pub async fn serve(config: crate::config::Config) -> AtomicServerResult<()> {
     let appstate = crate::appstate::init(config.clone())?;
 
     // Start async processes
-    #[cfg(feature = "desktop")]
-    crate::tray_icon::tray_icon_process(config.clone());
-
     if config.opts.rebuild_index {
         rebuild_index(&appstate)?;
     }
 
     let server = HttpServer::new(move || {
-        // The appstate can be accessed in Handlers using
-        // data: web::Data<Mutex<AppState>>
-        // In the argument of a handler function
-        let data = web::Data::new(Mutex::new(appstate.clone()));
-        // Allow requests from other domains
-        // let cors = Cors::default().allow_any_origin();
         let cors = Cors::permissive();
 
         actix_web::App::new()
-            .app_data(data)
+            .app_data(web::Data::new(appstate.clone()))
             .wrap(cors)
             .wrap(tracing_actix_web::TracingLogger::default())
             .wrap(middleware::Compress::default())
@@ -83,9 +73,7 @@ pub async fn serve(config: crate::config::Config) -> AtomicServerResult<()> {
             #[cfg(feature = "https")]
             {
                 // If there is no certificate file, or the certs are too old, start HTTPS initialization
-                if std::fs::File::open(&config.cert_path).is_err()
-                    || crate::https::check_expiration_certs(&config)
-                {
+                if crate::https::should_renew_certs_check(&config) {
                     crate::https::cert_init_server(&config).await?;
                 }
                 let https_config = crate::https::get_https_config(&config)
